==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fDdiv.h <==
// class soot.coffi.Instruction_Ddiv

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 2db235b4e1b7ca55 soot_coffi_Instruction__5fDdiv
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fDdiv_H_
#define _JC_soot_coffi_Instruction__5fDdiv_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fDdiv$sub_refs	_jc_soot_coffi_Instruction__5fDdiv$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs	_jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$refs	_jc_soot_coffi_Instruction__5fDdiv$refs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$nonrefs	_jc_soot_coffi_Instruction__5fDdiv$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$object	_jc_soot_coffi_Instruction__5fDdiv$object;

typedef const struct _jc_soot_coffi_Instruction__5fDdiv$vmethods	_jc_soot_coffi_Instruction__5fDdiv$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fDdiv$vtable	_jc_soot_coffi_Instruction__5fDdiv$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fDdiv$vtype	_jc_soot_coffi_Instruction__5fDdiv$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fDdiv$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fDdiv$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fDdiv$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fDdiv$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fDdiv$vmethods	soot_coffi_Instruction__5fDdiv;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fDdiv$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fDdiv$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDdiv$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDdiv$refs {
    _jc_soot_coffi_Instruction__5fDdiv$sub_refs	soot_coffi_Instruction__5fDdiv;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDdiv$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs	soot_coffi_Instruction__5fDdiv;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fDdiv$object {
	_jc_soot_coffi_Instruction__5fDdiv$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fDdiv$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fDdiv$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fDdiv$vtype _jc_soot_coffi_Instruction__5fDdiv$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fDdiv, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fDdiv$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fDdiv_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fDdiv.h <==
// class soot.coffi.Instruction_Ddiv

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 2db235b4e1b7ca55 soot_coffi_Instruction__5fDdiv
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fDdiv_H_
#define _JC_soot_coffi_Instruction__5fDdiv_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fDdiv$sub_refs	_jc_soot_coffi_Instruction__5fDdiv$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs	_jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$refs	_jc_soot_coffi_Instruction__5fDdiv$refs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$nonrefs	_jc_soot_coffi_Instruction__5fDdiv$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDdiv$object	_jc_soot_coffi_Instruction__5fDdiv$object;

typedef const struct _jc_soot_coffi_Instruction__5fDdiv$vmethods	_jc_soot_coffi_Instruction__5fDdiv$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fDdiv$vtable	_jc_soot_coffi_Instruction__5fDdiv$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fDdiv$vtype	_jc_soot_coffi_Instruction__5fDdiv$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fDdiv$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fDdiv$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fDdiv$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fDdiv$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fDdiv$vmethods	soot_coffi_Instruction__5fDdiv;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fDdiv$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fDdiv$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDdiv$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDdiv$refs {
    _jc_soot_coffi_Instruction__5fDdiv$sub_refs	soot_coffi_Instruction__5fDdiv;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDdiv$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fDdiv$sub_nonrefs	soot_coffi_Instruction__5fDdiv;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fDdiv$object {
	_jc_soot_coffi_Instruction__5fDdiv$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fDdiv$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fDdiv$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fDdiv$vtype _jc_soot_coffi_Instruction__5fDdiv$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fDdiv, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fDdiv$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fDdiv_H_ */
